@@ -1,8 +1,8 @@
 use std::fs;
-use std::fs::{ReadDir,DirEntry,File};
 use std::io::{Error,ErrorKind};
 use std::path::Path;
-use crate::bro;
+// use crate::bro;
+use crate::util;
 /// The creation of a directory is always a safe 
 /// operation i.e in case the folder already exists it 
 /// will return an error.
@@ -11,6 +11,7 @@ use crate::bro;
 ///  assert!(p_dir.is_ok());
 /// ``` 
 pub fn create_dir( dir_name:&str)->Result<bool,Error> {
+    // util::
     let complete = String::from("./") + &dir_name;
     let path = Path::new(&complete);
     //.................................................
